@@ -234,7 +234,8 @@ class FileStateManager:
         if addDefaults:
             stateDict = self.maybePopulateDefaults(stateDict)
         if watch and self.watcher:
-            self.watcher.removePaths(self.watcher.files())
+            if files := self.watcher.files():
+                self.watcher.removePaths(files)
             self.watcher.addPath(str(self.directory))
             self.watcher.addPath(str(filename))
         return stateDict
@@ -398,11 +399,12 @@ class ParameterEditor(QtWidgets.QWidget):
                 "No state name given and no default state name set; cannot save"
             )
         if stateDict is None:
-            stateDict = (
-                self.getParameterValues()
-                if (not addDefaults and not self.getDefaultStateName().exists())
-                else self.getParameterDefaults()
-            )
+            stateDict = self.getParameterValues()
+        if addDefaults:
+            _, defaults = self.stateManager.getDefaultStateName(returnStateDict=True)
+            if defaults is None:
+                defaults = self.getParameterDefaults()
+            stateDict = fns.hierarchicalUpdate(defaults, stateDict)
         if not blockWrite:
             # Don't trigger infinite "load" loops through file watcher signal
             # if saving self's current state
