@@ -5,14 +5,14 @@ import qtextras.widgets.easywidget
 from qtextras import ParameterEditor, widgets
 
 
-def test_dockgrouping(tmp_path):
+def dockgrouping(directory):
     pes = [ParameterEditor(name=str(ii)) for ii in range(3)]
     # grp = ParameterEditorDockGroup(pes, "Test Group")
     window = qtextras.widgets.easywidget.EasyWidget.buildMainWindow(
         [QtWidgets.QTextEdit(), QtWidgets.QPushButton("Test")]
     )
     # window.addDockWidget(QtCore.Qt.DockWidgetArea.RightDockWidgetArea, grp)
-    pe = ParameterEditor(name="test", directory=tmp_path)
+    pe = ParameterEditor(name="test", directory=directory)
 
     def myfunc(a=1):
         print("Test", a)
@@ -27,10 +27,12 @@ def test_dockgrouping(tmp_path):
 
     return window
 
+def test_dockgrouping(tmp_path):
+    assert dockgrouping(tmp_path)
 
 if __name__ == "__main__":
     pg.mkQApp()
-    win = test_dockgrouping(".")
+    win = dockgrouping(".")
     win.raise_()
     win.show()
     pg.exec()
